@@ -113,11 +113,6 @@ pub(super) fn set_rustflags() {
     std::env::set_var("RUSTFLAGS", "-C prefer-dynamic");
 }
 
-#[track_caller]
-pub(super) fn enable_experimental() {
-    std::env::set_var("NEXTEST_EXPERIMENTAL_REUSE_BUILD", "1");
-}
-
 #[track_caller]
 pub fn save_cargo_metadata(p: &TempProject) {
     let mut cmd = Command::new(cargo_bin());
